import request from '@/utils/request'
import {download} from '@/utils/request'
let currencyConfig ={
	"rows": [{
		"mid": "0a4",
		"name": "经度",
		"unit": "",
		"min": null,
		"max": null
	},{
		"mid": "0a5",
		"name": "纬度",
		"unit": "",
		"min": null,
		"max": null
	},{
		"mid": "0a9",
		"name": "对地航速",
		"unit": "kn",
		"min": 0.0,
		"max": 20.0
	},{
		"mid": "0aA",
		"name": "对地航向/船艏相",
		"unit": "°",
		"min": 0.0,
		"max": 360.0
	},{
		"mid": "0a8",
		"name": "真航向/航迹向",
		"unit": "°",
		"min": 0.0,
		"max": 360.0
	},{
		"mid": "005",
		"name": "左主机转速",
		"unit": "RPM",
		"min": 0.0,
		"max": 20.0
	},{
	   "mid": "0aS",
		"name": "测深仪",
		"unit": "m",
		"min": null,
		"max": null
	},{
		"mid": "06H",
		"name": "左发电机转速",
		"unit": "RPM",
		"min": null,
		"max": null
	},{
		"mid": "08H",
		"name": "右发电机转速",
		"unit": "RPM",
		"min": null,
		"max": null
	},{
		"mid": "0AH",
		"name": "中发电机转速",
		"unit": "RPM",
		"min": null,
		"max": null
	},{
		"mid": "060",
		"name": "左发电机冷却液温度",
		"unit": "℃",
		"min": null,
		"max": null
	},{
		"mid": "062",
		"name": "左发电机润滑油温度",
		"unit": "℃",
		"min": null,
		"max": null
	},{
	   "mid": "064",
		"name": "左发电机润滑油压力",
		"unit": "bar",
		"min": 0.0,
		"max": 20.0
	},{
		"mid": "066",
		"name": "左发电机电瓶电压",
		"unit": "V",
		"min": null,
		"max": null
	},{
		"mid": "068",
		"name": "左发电机累计运转时数",
		"unit": "hr",
		"min": null,
		"max": null
	}, {
		"mid": "080",
		"name": "右发电机冷却液温度",
		"unit": "℃",
		"min": null,
		"max": null
	},{
		"mid": "082",
		"name": "右发电机润滑油温度",
		"unit": "℃",
		"min": null,
		"max": null
	},{
		"mid": "084",
		"name": "右发电机润滑油压力",
		"unit": "bar",
		"min": 0.0,
		"max": 20.0
	},{
		"mid": "086",
		"name": "右发电机电瓶电压",
		"unit": "V",
		"min": null,
		"max": null
	},{
		"mid": "088",
		"name": "右发电机累计运转时数",
		"unit": "hr",
		"min": null,
		"max": null
	},{
		"mid": "0A0",
		"name": "中发电机冷却液温度",
		"unit": "℃",
		"min": null,
		"max": null
	},{
		"mid": "0A2",
		"name": "中发电机润滑油温度",
		"unit": "℃",
		"min": null,
		"max": null
	},{
		"mid": "0A4",
		"name": "中发电机润滑油压力",
		"unit": "bar",
		"min": 0.0,
		"max": 20.0
	},{
		"mid": "0A6",
		"name": "中发电机电瓶电压",
		"unit": "V",
		"min": null,
		"max": null
	},{
		"mid": "0A8",
		"name": "中发电机累计运转时数",
		"unit": "hr",
		"min": null,
		"max": null
	},{
		"mid": "0hL",
		"name": "左1#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	}, {
		"mid": "0hM",
		"name": "右1#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hN",
		"name": "左2#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},
	{
	   "mid": "0hO",
		"name": "右2#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},
	{
		"mid": "0hP",
		"name": "左3#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},
	{
		"mid": "0hQ",
		"name": "右3#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hR",
		"name": "左4#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hS",
		"name": "右4#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hT",
		"name": "左5#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hU",
		"name": "右5#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hV",
		"name": "左6#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hW",
		"name": "右6#液货舱液位",
		"unit": "m",
		"min": null,
		"max": 6.55
	},{
		"mid": "0hX",
		"name": "左1#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hY",
		"name": "左2#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hZ",
		"name": "左3#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0ha",
		"name": "左4#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hb",
		"name": "左5#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hc",
		"name": "左6#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hd",
		"name": "右1#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0he",
		"name": "右2#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hf",
		"name": "右3#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hg",
		"name": "右4#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		"mid": "0hh",
		"name": "右5#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
		
		"mid": "0hi",
		"name": "右6#液货舱压力",
		"unit": "Kpa",
		"min": null,
		"max": null
	},{
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:10",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33019,
            "mid": "0gd",
            "name": "左5#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33020,
            "mid": "0ge",
            "name": "左5#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33021,
            "mid": "0gf",
            "name": "左5#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33022,
            "mid": "0gg",
            "name": "左6#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33023,
            "mid": "0gh",
            "name": "左6#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33024,
            "mid": "0gi",
            "name": "左6#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33025,
            "mid": "0gj",
            "name": "右5#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33026,
            "mid": "0gk",
            "name": "右5#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33027,
            "mid": "0gl",
            "name": "右5#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33028,
            "mid": "0gm",
            "name": "右6#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:11",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33029,
            "mid": "0gn",
            "name": "右6#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33030,
            "mid": "0go",
            "name": "右6#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33031,
            "mid": "0gp",
            "name": "左1#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33032,
            "mid": "0gq",
            "name": "左1#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33033,
            "mid": "0gr",
            "name": "左1#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33034,
            "mid": "0gs",
            "name": "左2#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33035,
            "mid": "0gt",
            "name": "左2#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33036,
            "mid": "0gu",
            "name": "左2#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33037,
            "mid": "0gv",
            "name": "左3#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33038,
            "mid": "0gw",
            "name": "左3#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33039,
            "mid": "0gx",
            "name": "左3#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:12",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33040,
            "mid": "0gy",
            "name": "左4#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:13",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33041,
            "mid": "0gz",
            "name": "左4#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:13",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33042,
            "mid": "0h0",
            "name": "左4#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:13",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33043,
            "mid": "0h1",
            "name": "右1#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:13",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33044,
            "mid": "0h2",
            "name": "右1#液货舱中部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:13",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33045,
            "mid": "0h3",
            "name": "右1#液货舱下部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "searchValue": null,
            "createBy": null,
            "createTime": "2023-06-14 14:49:13",
            "updateBy": null,
            "updateTime": null,
            "remark": "",
            "params": {},
            "id": 33046,
            "mid": "0h4",
            "name": "右2#液货舱上部温度",
            "tid": 132,
            "unit": "℃",
            "min": null,
            "max": 100.0,
            "midType": null
        },
        {
            "mid": "0h5",
            "name": "右2#液货舱中部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },
        {
            "mid": "0h6",
            "name": "右2#液货舱下部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },{
            "mid": "0h7",
            "name": "右3#液货舱上部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },{
            "mid": "0h8",
            "name": "右3#液货舱中部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },{
            "mid": "0h9",
            "name": "右3#液货舱下部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },{
            "mid": "0hA",
            "name": "右4#液货舱上部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },{
			"mid": "0hB",
            "name": "右4#液货舱中部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        },{
           "mid": "0hC",
            "name": "右4#液货舱下部温度",
            "unit": "℃",
            "min": null,
            "max": 100.0
        }]
}
// 查询通用数据配置表列表
export function listCurrencyConfig(query) {
	// return new Promise((resolve, reject) => {
	// 	setTimeout(() => {
	// 		resolve(JSON.parse(JSON.stringify(currencyConfig)));
	// 	}, 100)
	// })
    return request({
        url: '/currencyConfig/currencyConfig/list',
        method: 'get',
        params: query
    })
}

// 查询通用数据配置表详细
export function getCurrencyConfig(id) {
    return request({
        url: '/currencyConfig/currencyConfig/' + id,
        method: 'get'
    })
}

// 新增通用数据配置表
export function addCurrencyConfig(data) {
    return request({
        url: '/currencyConfig/currencyConfig',
        method: 'post',
        data: data
    })
}

// 修改通用数据配置表
export function updateCurrencyConfig(data) {
    return request({
        url: '/currencyConfig/currencyConfig',
        method: 'put',
        data: data
    })
}

// 删除通用数据配置表
export function delCurrencyConfig(id) {
    return request({
        url: '/currencyConfig/currencyConfig/' + id,
        method: 'delete'
    })
}

// 导出通用数据配置表
export function downloadCurrencyConfig(data) {
    download(
        '/currencyConfig/currencyConfig/export',
        data,
        `currencyConfig_${new Date().getTime()}.xlsx`)
}
