<template>

  <div class="app-container">

    <!-- <van-pull-refresh class="mobile-app-container" v-model="loading" :success-text="$store.state.data.successText" @refresh="handlePullDownRefresh">
      <van-sticky :offset-top="$store.state.data.showNavBar?46:0">
        <van-search class="solid-bottom" v-model="queryParams.CurrencyConfigName" show-action placeholder="请输入搜索关键词" @search="handleQuery">
          <template #action>
            <div @click="handleQuery">搜索</div>
          </template>
        </van-search>
      </van-sticky>
      <van-list v-model:loading="loading" :finished="currencyConfigList.length >= total" :finished-text="$store.state.data.finishedText" @load="handleReachBottom" v-if="currencyConfigList.length > 0">
        <template v-for="item in currencyConfigList" :key="item.currencyConfigId">
          <van-cell-group class="margin-tb-xs">
            <van-cell title="主键id" :value="item.id" />
            <van-cell title="测点编码MID" :value="item.mid" />
            <van-cell title="数据项目" :value="item.name" />
            <van-cell title="类型" :value="item.tid" />
            <van-cell title="单位" :value="item.unit" />
            <van-cell title="最小值" :value="item.min" />
            <van-cell title="最大值" :value="item.max" />
          </van-cell-group>
        </template>
      </van-list>
      <van-skeleton :row="$columns.size" v-if="loading" />
      <van-empty :description="$store.state.data.emptyDescription" v-else-if="loading == false&&currencyConfigList.length == 0" />

    </van-pull-refresh> -->

    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="测点编码MID" prop="mid">
        <el-input v-model="queryParams.mid" placeholder="请输入测点编码MID" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="数据项目" prop="name">
        <el-input v-model="queryParams.name" placeholder="请输入数据项目" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="类型" prop="tid">
        <el-input v-model="queryParams.tid" placeholder="请输入类型" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="单位" prop="unit">
        <el-input v-model="queryParams.unit" placeholder="请输入单位" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="最小值" prop="min">
        <el-input v-model="queryParams.min" placeholder="请输入最小值" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="最大值" prop="max">
        <el-input v-model="queryParams.max" placeholder="请输入最大值" clearable @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['currencyConfig:currencyConfig:add']">新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate" v-hasPermi="['currencyConfig:currencyConfig:edit']">修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete" v-hasPermi="['currencyConfig:currencyConfig:remove']">删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['currencyConfig:currencyConfig:export']">导出
        </el-button>
      </el-col>
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="currencyConfigList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <!-- <el-table-column label="主键id" align="center" prop="id" /> -->
      <el-table-column label="测点编码MID" align="center" prop="mid" />
      <el-table-column label="数据项目" align="center" prop="name" />
      <el-table-column label="类型" align="center" prop="tid" />
      <el-table-column label="单位" align="center" prop="unit" />
      <el-table-column label="最小值" align="center" prop="min" />
      <el-table-column label="最大值" align="center" prop="max" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="200" fixed="right">
        <template #default="scope">
          <!-- <el-button type="primary" link icon="View" @click="handleView(scope.row)" v-hasPermi="['currencyConfig:currencyConfig:query']" >详细
          </el-button> -->
          <el-button type="success" link icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['currencyConfig:currencyConfig:edit']">修改
          </el-button>
          <el-button type="danger" link icon="Delete" @click="handleDelete(scope.row)" v-hasPermi="['currencyConfig:currencyConfig:remove']">删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total>0" :total="total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改通用数据配置表对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="currencyConfigRef" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="测点编码MID" prop="mid">
          <el-input v-model="form.mid" placeholder="请输入测点编码MID" :disabled="form.id!=null" />
        </el-form-item>
        <el-form-item label="数据项目" prop="name">
          <el-input v-model="form.name" placeholder="请输入数据项目" />
        </el-form-item>
        <el-form-item label="类型" prop="tid">
          <el-input v-model="form.tid" placeholder="请输入类型" />
        </el-form-item>
        <el-form-item label="单位" prop="unit">
          <el-input v-model="form.unit" placeholder="请输入单位" />
        </el-form-item>
        <el-form-item label="最小值" prop="min">
          <el-input v-model="form.min" placeholder="请输入最小值" type="number" />
        </el-form-item>
        <el-form-item label="最大值" prop="max">
          <el-input v-model="form.max" placeholder="请输入最大值" type="number" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>

</template>

<script setup name="CurrencyConfig">
import {
  listCurrencyConfig,
  getCurrencyConfig,
  delCurrencyConfig,
  addCurrencyConfig,
  updateCurrencyConfig,
} from "@/api/currencyConfig/currencyConfig";
import useCurrencyConfig from "@/hooks/useCurrencyConfig"; // hook

import { getCurrencyConfigByName, getCurrencyConfigByMid } from "@/utils/index";
console.log(getCurrencyConfigByName("经度"));
console.log(getCurrencyConfigByMid("0a4"));

const { proxy } = getCurrentInstance();
const currencyConfigList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    mid: null,
    name: null,
    tid: null,
    unit: null,
    min: null,
    max: null,
  },
  rules: {
    mid: [
      {
        required: true,
        message: "测点编码MID不能为空",
        trigger: "blur",
      },
    ],
    name: [
      {
        required: true,
        message: "数据项目不能为空",
        trigger: "blur",
      },
    ],
    tid: [
      {
        required: true,
        message: "类型不能为空",
        trigger: "blur",
      },
    ],
  },
});
const { queryParams, form, rules } = toRefs(data);
const baseUrl = import.meta.env.VITE_APP_BASE_API;

/** 查询通用数据配置表列表 */
function getList() {
  console.log(getCurrencyConfigByName("经度"));
  console.log(getCurrencyConfigByMid("0a4"));
  //   console.log(JSON.stringify(proxy.$store.state.data.currencyConfigList));
  loading.value = true;
  listCurrencyConfig(queryParams.value).then((response) => {
    currencyConfigList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}

function addList() {
  loading.value = true;
  listCurrencyConfig(queryParams.value)
    .then((response) => {
      currencyConfigList.value.push(...response.rows);
      total.value = response.total;
      if (currencyConfigList.value.length >= total.value) finished.value = true;
      loading.value = false;
    })
    .catch((response) => {
      loading.value = false;
    });
}

// 下拉刷新
function handlePullDownRefresh() {
  queryParams.value.pageNum = 1;
  currencyConfigList.value = [];
  addList();
}

// 滚动到底部的事件
function handleReachBottom() {
  queryParams.value.pageNum++;
  addList();
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    mid: null,
    name: null,
    tid: null,
    unit: null,
    min: null,
    max: null,
    createTime: null,
  };
  proxy.resetForm("currencyConfigRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map((item) => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加通用数据配置表";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const id = row.id || ids.value;
  getCurrencyConfig(id).then((response) => {
    form.value = response.data;
    open.value = true;
    title.value = "修改通用数据配置表";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["currencyConfigRef"].validate((valid) => {
    if (valid) {
      if (form.value.id != null) {
        updateCurrencyConfig(form.value).then((response) => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
          useCurrencyConfig();
        });
      } else {
        addCurrencyConfig(form.value).then((response) => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const ids = row.id || ids.value;
  proxy.$modal
    .confirm('是否确认删除通用数据配置表编号为"' + ids + '"的数据项？')
    .then(function () {
      return delCurrencyConfig(ids);
    })
    .then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
    })
    .catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  downloadCurrencyConfig(queryParams.value);
  // proxy.download('currencyConfig/currencyConfig/export', {
  //   ...queryParams.value
  // }, `currencyConfig_${new Date().getTime()}.xlsx`)
}

/** 详细按钮操作 */
function handleView(row) {}

getList();
</script>

